@@ -101,7 +101,7 @@ changed_bg_pixmap (GtkWidget *w, GtkHTMLEditTableProperties *d)
 		return;
 
 	html_cursor_forward (d->cd->html->engine->cursor, d->cd->html->engine);
-	file = gtk_entry_get_text (GTK_ENTRY (w));
+	file = (const char *) gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (w));
 	url = gtk_html_filename_to_uri (file);
 	html_engine_table_set_bg_pixmap (d->cd->html->engine, d->table, url);
 	g_free (url);
@@ -246,8 +246,8 @@ table_widget (GtkHTMLEditTableProperties *d)
 	gtk_box_pack_start (GTK_BOX (glade_xml_get_widget (xml, "bg_color_hbox")), d->combo_bg_color, FALSE, FALSE, 0);
 
 	d->entry_bg_pixmap = glade_xml_get_widget (xml, "entry_table_bg_pixmap");
-	g_signal_connect (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (d->entry_bg_pixmap)),
-			  "changed", G_CALLBACK (changed_bg_pixmap), d);
+	g_signal_connect (GTK_FILE_CHOOSER_BUTTON (d->entry_bg_pixmap),
+			  "selection-changed", G_CALLBACK (changed_bg_pixmap), d);
 
 	d->spin_spacing = glade_xml_get_widget (xml, "spin_spacing");
 	g_signal_connect (d->spin_spacing, "value_changed", G_CALLBACK (changed_spacing), d);
@@ -280,7 +280,7 @@ table_widget (GtkHTMLEditTableProperties *d)
 	UPPER_FIX (rows);
 
 	gtk_widget_show_all (table_page);
-	gnome_pixmap_entry_set_preview (GNOME_PIXMAP_ENTRY (d->entry_bg_pixmap), FALSE);
+	gtk_file_chooser_set_preview_widget_active (GTK_FILE_CHOOSER (d->entry_bg_pixmap), FALSE);
 
 	return table_page;
 }
@@ -301,7 +301,7 @@ set_ui (GtkHTMLEditTableProperties *d)
 		if (d->table->bgPixmap) {
 			gchar *filename = gtk_html_filename_from_uri (d->table->bgPixmap->url);
 
-			gtk_entry_set_text (GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (d->entry_bg_pixmap))),
+			gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (d->entry_bg_pixmap),
 					    filename);
 			g_free (filename);
 		}
